@@ -384,16 +384,16 @@ class PseudoAgentDBBindingController(port_binding.PortBindingController):
 
             if self._hconfig_bind_port(port_context, hconfig):
                 break  # Port binding suceeded!
-            else:  # Port binding failed!
-                LOG.warning(
-                    "Failed to bind Port %(pid)s devid %(device_id)s "
-                    "owner %(owner)s for host %(host)s "
-                    "on network %(network)s.", {
-                        'pid': port_context.current['id'],
-                        'device_id': port_context.current['device_id'],
-                        'owner': port_context.current['device_owner'],
-                        'host': port_context.host,
-                        'network': port_context.network.current['id']})
+            # Port binding failed!
+            LOG.warning(
+                "Failed to bind Port %(pid)s devid %(device_id)s "
+                "owner %(owner)s for host %(host)s "
+                "on network %(network)s.", {
+                    'pid': port_context.current['id'],
+                    'device_id': port_context.current['device_id'],
+                    'owner': port_context.current['device_owner'],
+                    'host': port_context.host,
+                    'network': port_context.network.current['id']})
         else:  # No hostconfig found for host in agentdb.
             LOG.warning("No ODL hostconfigs for host %s found in agentdb",
                         port_context.host)
